#!/bin/bash

if [ "$(id -u)" != "0" ]; then
    echo "请使用root权限执行此脚本！" 1>&2
    exit 1
fi

# PHP安装目录
php_install_dir="/www/server/php"
# Swoole Loader下载基础URL
base_url="http://file.cccyun.cc/swoole-loader/3.2/linux"

# 检测可用的PHP版本
versions=()
for dir in "${php_install_dir}"/*; do
    if [ -d "${dir}" ] && [ -x "${dir}/bin/php" ]; then
        version=$(basename "${dir}")
        versions+=("${version}")
    fi
done

if [ ${#versions[@]} -eq 0 ]; then
    echo "在 ${php_install_dir} 路径下未找到可用的PHP版本"
    exit 1
fi

# 选择PHP版本
selected_version=""
if [ ${#versions[@]} -eq 1 ]; then
    selected_version=${versions[0]}
    echo "已选中的PHP版本: ${selected_version}"
else
    echo "检测到多个PHP版本:"
    for i in "${!versions[@]}"; do
        echo "$((i+1)). PHP ${versions[$i]}"
    done
    while true; do
        read -p "请选择PHP版本 (1-${#versions[@]}): " choice
        if [[ $choice =~ ^[0-9]+$ ]] && [ $choice -ge 1 ] && [ $choice -le ${#versions[@]} ]; then
            selected_version=${versions[$((choice-1))]}
            break
        else
            echo "输入无效。请输入 1 到 ${#versions[@]}."
        fi
    done
    echo "已选中的PHP版本: ${selected_version}"
fi

# 确定路径
php_path="${php_install_dir}/${selected_version}"
php_config="${php_path}/bin/php-config"
ext_dir=$("${php_config}" --extension-dir)
php_ini="${php_path}/etc/php.ini"
php_cli_ini="${php_path}/etc/php-cli.ini"

# 检查必要文件
if [ ! -f "${php_ini}" ]; then
    echo "php.ini not found at ${php_ini}"
    exit 1
fi

# 构造下载URL
ext_file="swoole_loader_${selected_version}_nts.so";
download_url="${base_url}/${ext_file}"
echo "正在下载 Swoole Loader"

# 下载扩展
if ! wget -qO "${ext_dir}/${ext_file}" "${download_url}"; then
    echo "Swoole Loader 下载失败"
    exit 1
fi

# 修改php.ini
if grep -q "${ext_file}" "${php_ini}"; then
    echo "php.ini 的 Swoole Loader 扩展已启用"
else
    echo -e "\nextension=${ext_file}" >> "${php_ini}"
    echo "成功在 php.ini 中添加了 Swoole Loader 扩展"
fi

# 修改php-cli.ini
if [ -f "${php_cli_ini}" ]; then
    if grep -q "${ext_file}" "${php_cli_ini}"; then
        echo "php-cli.ini 的 Swoole Loader 扩展已启用"
    else
        echo -e "\nextension=${ext_file}" >> "${php_cli_ini}"
        echo "成功在 php-cli.ini 中添加了 Swoole Loader 扩展"
    fi
fi

# 重启PHP-FPM服务
echo "正在重启 PHP ${selected_version}"
/etc/init.d/php-fpm-${selected_version} restart

# 验证安装
if "${php_path}/bin/php" -m | grep -q "swoole_loader"; then
    echo "已成功为 PHP ${selected_version} 安装 Swoole Loader 扩展!"
else
    echo "安装成功但 Swoole Loader 扩展未加载，请检查配置"
fi
